@@ -3,20 +3,38 @@ package Lemonldap::NG::Handler::PSGI::Try;
 use strict;
 use Mouse;
 
-our $VERSION = '2.0.3';
+our $VERSION = '2.0.14';
 
 extends 'Lemonldap::NG::Handler::PSGI::Router';
 
 has 'authRoutes' => (
     is      => 'rw',
     isa     => 'HashRef',
-    default => sub { { GET => {}, POST => {}, PUT => {}, DELETE => {} } }
+    default => sub {
+        {
+            GET     => {},
+            POST    => {},
+            PUT     => {},
+            PATCH   => {},
+            DELETE  => {},
+            OPTIONS => {}
+        }
+    }
 );
 
 has 'unAuthRoutes' => (
     is      => 'rw',
     isa     => 'HashRef',
-    default => sub { { GET => {}, POST => {}, PUT => {}, DELETE => {} } }
+    default => sub {
+        {
+            GET     => {},
+            POST    => {},
+            PUT     => {},
+            PATCH   => {},
+            DELETE  => {},
+            OPTIONS => {}
+        }
+    }
 );
 
 sub addRoute {
@@ -47,7 +65,7 @@ sub addAuthRouteWithRedirect {
 sub _auth_and_redirect {
     my ( $self, $req ) = @_;
     $self->api->goToPortal( $req, $req->{env}->{REQUEST_URI} );
-    return [ 302, $req->respHeaders, [] ];
+    return [ 302, [ $req->spliceHdrs ], [] ];
 }
 
 sub defaultAuthRoute {
@@ -67,12 +85,13 @@ sub _run {
 
     return sub {
         my $req = Lemonldap::NG::Common::PSGI::Request->new( $_[0] );
-        my $res = $self->_authAndTrace( $req, 1 );
+        my $res = $self->_logAuthTrace( $req, 1 );
         if ( $res->[0] < 300 ) {
             $self->routes( $self->authRoutes );
             $req->userData( $self->api->data );
+            $req->respHeaders( $res->[1] );
         }
-        elsif ( $res->[0] != 403 ) {
+        elsif ( $res->[0] != 403 and not $req->data->{noTry} ) {
 
             # Unset headers (handler adds a Location header)
             $self->logger->debug(
@@ -84,18 +103,11 @@ sub _run {
         else {
             return $res;
         }
-        $res = $self->handler($req);
-
-        # Insert respHeaders in response only if not already set
-        my %hdr1 = @{ $res->[1] };
-        my %hdr2 = @{ $req->{respHeaders} };
-        foreach ( keys %hdr2 ) {
-            unless ( $hdr1{$_} and $hdr2{$_} eq $hdr1{$_} ) {
-                push @{ $res->[1] }, ( $_ => $hdr2{$_} );
-            }
-        }
+        $res = $self->_logAndHandle($req);
+        push @{ $res->[1] }, $req->spliceHdrs;
         return $res;
     };
+
 }
 
 1;
@@ -193,7 +205,7 @@ L<https://gitlab.ow2.org/lemonldap-ng/lemonldap-ng/issues>
 =head1 DOWNLOAD
 
 Lemonldap::NG is available at
-L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
+L<https://lemonldap-ng.org/download>
 
 =head1 COPYRIGHT AND LICENSE
 
